def main():
 Hokkaido = 961
 print('Hokkaido', Hokkaido)
 Aomori = 1002
 print('Aomori', Aomori)
 Iwate = 922
 print('Iwate', Iwate)
 Miyagi = 996
 print('Miyagi', Miyagi)
 Akita = 984
 print('Akita', Akita)
 Yamagata = 920
 print('Yamagata', Yamagata)
 Fukushima = 1042
 print('Fukushima', Fukushima)
 Ibaraki = 985
 print('Ibaraki', Ibaraki)
 Tochigi = 921
 print('Tochigi', Tochigi)
 Gunma = 986
 print('Gunma', Gunma)
 Saitama = 858
 print('Saitama', Saitama)
 Chiba = 903
 print('Chiba', Chiba)
 Tokyo = 888
 print('Tokyo', Tokyo)
 Kanagawa = 858
 print('Kanagawa', Kanagawa)
 Niigata = 1017
 print('Niigata', Niigata)
 Toyama = 1044
 print('Toyama', Toyama)
 Ishikawa = 968
 print('Ishikawa', Ishikawa)
 Fukui = 981
 print('Fukui', Fukui)
 Yamanashi = 968
 print('Yamanashi', Yamanashi)
 Nagano = 817
 print('Nagano', Nagano)
 Gifu = 892
 print('Gifu', Gifu)
 Shizuoka = 878
 print('Shizuoka', Shizuoka)
 Aichi = 916
 print('Aichi', Aichi)
 Mie = 943
 print('Mie', Mie)
 Shiga = 830
 print('Shiga', Shiga)
 Kyoto = 843
 print('Kyoto', Kyoto)
 Osaka = 945
 print('Osaka', Osaka)
 Hyogo = 938
 print('Hyogo', Hyogo)
 Nara = 909
 print('Nara', Nara)
 Wakayama = 942
 print('Wakayama', Wakayama)
 Tottori = 1050
 print('Tottori', Tottori)
 Shimane = 946
 print('Shimane', Shimane)
 Okayama = 993
 print('Okayama', Okayama)
 Hiroshima = 891
 print('Hiroshima', Hiroshima)
 Yamaguchi = 986
 print('Yamaguchi', Yamaguchi)
 Tokushima = 946
 print('Tokushima', Tokushima)
 Kagawa = 869
 print('Kagawa', Kagawa)
 Ehime = 902
 print('Ehime', Ehime)
 Kochi = 954
 print('Kochi', Kochi)
 Fukuoka = 954
 print('Fukuoka', Fukuoka)
 Saga = 889
 print('Saga', Saga)
 Nagasaki = 952
 print('Nagasaki', Nagasaki)
 Kumamoto = 922
 print('Kumamoto', Kumamoto)
 Oita = 936
 print('Oita', Oita)
 Miyazaki = 956
 print('Miyazaki', Miyazaki)
 Kagoshima = 918
 print('Kagoshima', Kagoshima)
 Okinawa = 868
 print('Okinawa', Okinawa)

if __name__ == "__main__":
 main()
